@@ -4,15 +4,15 @@
 
 //!
 //!
-//! QueryMap is a generic wrapper around HashMap<String, Vec<String>>
+//! `QueryMap` is a generic wrapper around `HashMap<String, Vec<String>>`
 //! to handle different transformations like URL query strings.
 //!
-//! QueryMap can normalize HashMap structures with single value elements
+//! `QueryMap` can normalize `HashMap` structures with single value elements
 //! into structures with value vector elements.
 //!
 //! # Examples
 //!
-//! Create a QueryMap from a HashMap:
+//! Create a `QueryMap` from a `HashMap`:
 //!
 //! ```
 //! use std::collections::HashMap;
@@ -26,10 +26,11 @@
 //! assert_eq!(None, map.first("bar"));
 //! ```
 //!
-//! Create a QueryMap from a Serde Value (requires `serde` feature):
+//! Create a `QueryMap` from a Serde Value (requires `serde` feature):
 //!
 //! ```ignore
 //! use query_map::QueryMap;
+//! use query_map::serde::standard::*;
 //!
 //! #[derive(Deserialize)]
 //! struct Test {
@@ -46,7 +47,7 @@
 //! assert_eq!("bar", test.data.first("foo").unwrap());
 //! ```
 //!
-//! Create a QueryMap from a query string (requires `url-query` feature):
+//! Create a `QueryMap` from a query string (requires `url-query` feature):
 //!
 //! ```
 //! use query_map::QueryMap;
@@ -59,15 +60,12 @@
 //!
 
 use std::{
-    collections::{hash_map::Entry::*, hash_map::Keys, HashMap},
+    collections::{hash_map::Keys, HashMap},
     sync::Arc,
 };
 
 #[cfg(feature = "serde")]
-mod serde;
-
-#[cfg(feature = "serde")]
-pub use crate::serde::*;
+pub mod serde;
 
 #[cfg(feature = "serde")]
 #[macro_use]
@@ -88,6 +86,7 @@ pub struct QueryMap(pub(crate) Arc<HashMap<String, Vec<String>>>);
 
 impl QueryMap {
     /// Return the first elelemnt associated with a key
+    #[must_use]
     pub fn first(&self, key: &str) -> Option<&str> {
         self.0
             .get(key)
@@ -95,6 +94,7 @@ impl QueryMap {
     }
 
     /// Return all elements associated with a key
+    #[must_use]
     pub fn all(&self, key: &str) -> Option<Vec<&str>> {
         self.0
             .get(key)
@@ -102,11 +102,13 @@ impl QueryMap {
     }
 
     /// Return true if there are no elements in the map
+    #[must_use]
     pub fn is_empty(&self) -> bool {
         self.0.is_empty()
     }
 
     /// Return an iterator for this map
+    #[must_use]
     pub fn iter(&self) -> QueryMapIter<'_> {
         QueryMapIter {
             data: self,
@@ -131,17 +133,9 @@ impl From<HashMap<String, Vec<String>>> for QueryMap {
 
 impl From<HashMap<String, String>> for QueryMap {
     fn from(inner: HashMap<String, String>) -> Self {
-        let mut map: HashMap<String, Vec<String>> = HashMap::new();
-        for (k, v) in inner {
-            match map.entry(k) {
-                Occupied(entry) => {
-                    entry.into_mut().push(v);
-                }
-                Vacant(entry) => {
-                    entry.insert(vec![v]);
-                }
-            };
-        }
+        // A `HashMap` cannot have repeated (key, value) pairs
+        let map: HashMap<String, Vec<String>> =
+            inner.into_iter().map(|(k, v)| (k, vec![v])).collect();
         QueryMap(Arc::new(map))
     }
 }
